package com.fs.fastGpt.service;

import com.fs.fastGpt.domain.FastgptTagGroup;

import java.util.List;

/**
 * ai标签组Service接口
 *
 * @author fs
 * @date 2024-12-20
 */
public interface IFastgptTagGroupService
{
    /**
     * 查询ai标签组
     *
     * @param id ai标签组主键
     * @return ai标签组
     */
    public FastgptTagGroup selectFastgptTagGroupById(Long id);

    /**
     * 查询ai标签组列表
     *
     * @param fastgptTagGroup ai标签组
     * @return ai标签组集合
     */
    public List<FastgptTagGroup> selectFastgptTagGroupList(FastgptTagGroup fastgptTagGroup);

    /**
     * 新增ai标签组
     *
     * @param fastgptTagGroup ai标签组
     * @return 结果
     */
    public int insertFastgptTagGroup(FastgptTagGroup fastgptTagGroup);

    /**
     * 修改ai标签组
     *
     * @param fastgptTagGroup ai标签组
     * @return 结果
     */
    public int updateFastgptTagGroup(FastgptTagGroup fastgptTagGroup);

    /**
     * 批量删除ai标签组
     *
     * @param ids 需要删除的ai标签组主键集合
     * @return 结果
     */
    public int deleteFastgptTagGroupByIds(Long[] ids);

    /**
     * 删除ai标签组信息
     *
     * @param id ai标签组主键
     * @return 结果
     */
    public int deleteFastgptTagGroupById(Long id);
}
